/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.controllers.rel

import com.persagy.base.extensions.toJson
import com.persagy.server.datacenter.models.entities.rel.REqSyList
import com.persagy.server.datacenter.models.entities.rel.RSyEq
import com.persagy.server.datacenter.models.entities.rel.RSyEqList
import com.persagy.server.services.rel.RSyEqService
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.v3.oas.annotations.Operation
import io.swagger.v3.oas.annotations.tags.Tag
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 *系统下的设备设施
 *
 * @author 张维新
 */
@Tag(name = "019、关系-系统下的设备设施")
@RestController
@RequestMapping("/rel/sy-in-eq")
class RSyEqController {
    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RSyEqController::class.java)
    } // Companion object

    /**
     * 创建系统下的设备关系
     *
     * @param   rSyEq           系统和设备的关系对象
     * @return                  创建结果信息
     */
    @Operation(summary = "创建系统下的设备关系", description = "必填项：EquipID（设备id）、SysID(系统id)")
    @PostMapping(value = ["/link"])
    fun create(@RequestBody rSyEq: RSyEq): SCreateResponse<RSyEq> {
        logger.debug("equip =${rSyEq.toJson()}")
        return RSyEqService.create(rSyEq)
    } // Function create()

    /**
     * 根据对象删除关系
     *
     * @param   rSyEq      对象
     * @return             删除的结果信息
     */
    @Operation(summary = "根据对象删除系统和设备的关系，只针对一个对象", description = "必填项：EquipID（设备id）、SysID(系统id)")
    @PostMapping(value = ["/unlink"])
    fun delete(@RequestBody rSyEq: RSyEq): SBaseResponse {
        return RSyEqService.deletes(rSyEq)
    } // Function delete()

    /**
     * 创建系统下的设备关系
     *
     * @param   rSyEq           系统和设备的关系对象
     * @return                  创建结果信息
     */
    @Operation(summary = "系统下的设备，系统一对多，数据覆盖", description = "必填项：EquipIdList（设备id列表）、SysID(系统id)，测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-eq"])
    fun createEq(@RequestBody rSyEq: RSyEqList): SCreateResponse<RSyEq> {
        logger.debug("equip =${rSyEq.toJson()}")
        return RSyEqService.createSy(rSyEq)
    } // Function createEq()

    /**
     * 创建系统下的设备关系
     *
     * @param   rSyEq           系统和设备的关系对象
     * @return                  创建结果信息
     */
    @Operation(summary = "设备关联系统，设备一对多， 数据覆盖", description = "必填项：EquipId（设备id）、sysIdList(系统id列表)，测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sy"])
    fun createSy(@RequestBody rSyEq: REqSyList): SCreateResponse<RSyEq> {
        logger.debug("equip =${rSyEq.toJson()}")
        return RSyEqService.createsEq(rSyEq)
    } // Function createSy()

    /**
     * 创建系统下的设备关系
     *
     * @param   rSyEq           系统和设备的关系对象
     * @return                  创建结果信息
     */
    @Operation(summary = "设备关联系统，系统一对多,数据叠加", description = "必填项：EquipId（设备id）、sysIdList(系统id列表)，此方法会为累计叠加，不会覆盖以前的数据")
    @PostMapping(value = ["/link-sy-eq"])
    fun createSyEq(@RequestBody rSyEq: RSyEqList): SCreateResponse<RSyEq> {
        logger.debug("equip =${rSyEq.toJson()}")
        return RSyEqService.createSyEq(rSyEq)
    } // Function createSyEq()

    /**
     * 根据对象删除系统和设备的关系
     *
     * @param   rSyEq           根据对象删除系统和设备的关系
     * @return                  创建结果信息
     */
    @Operation(summary = "根据对象删除系统和设备的关系", description = "必填项：EquipID（设备id）、SysID(系统id)")
    @PostMapping(value = ["/unlinks-sy-eq"])
    fun deleteRSyEq(@RequestBody idList: ArrayList<RSyEq>): SBaseResponse {
        logger.debug("equip =${idList.toJson()}")
        return RSyEqService.deleteByKeysList(idList)
    }

}